==> icons-vue-0.3.0.tgz: package/es/sunset/24.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../chunk-75bb93d0.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_Sunset24 = {
  name: 'Sunset24',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '24',
      height: '24',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M2 27.005H29.998V29.005H2z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M16,20a4.0045,4.0045,0,0,1,4,4h2a6,6,0,0,0-12,0h2A4.0045,4.0045,0,0,1,16,20Z",
        "transform": "translate(0 .005)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M25 22.005H30V24.005H25z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M21.668 14.854H26.625999999999998V16.854H21.668z",
        "transform": "rotate(-45 24.152 15.856)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M19.59 9.595L17 12.175 17 4.005 15 4.005 15 12.175 12.41 9.595 11 11.005 16 16.005 21 11.005 19.59 9.595z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M6.854 13.374H8.854V18.332H6.854z",
        "transform": "rotate(-45 7.86 15.856)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M2 22.005H7V24.005H2z"
      }
    }), children]);
  }
};

export default virtual_Sunset24;

==> icons-vue-0.6.0.tgz: package/es/sunset/24.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../_rollupPluginBabelHelpers-8169a350.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_Sunset24 = {
  name: 'Sunset24',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '24',
      height: '24',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('rect', {
      attrs: {
        "width": "27.998",
        "height": "2",
        "x": "2",
        "y": "27.005"
      }
    }), createElement('path', {
      attrs: {
        "d": "M16,20a4.0045,4.0045,0,0,1,4,4h2a6,6,0,0,0-12,0h2A4.0045,4.0045,0,0,1,16,20Z",
        "transform": "translate(0 .005)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "5",
        "height": "2",
        "x": "25",
        "y": "22.005"
      }
    }), createElement('rect', {
      attrs: {
        "width": "4.958",
        "height": "2",
        "x": "21.668",
        "y": "14.854",
        "transform": "rotate(-45 24.152 15.856)"
      }
    }), createElement('polygon', {
      attrs: {
        "points": "19.59 9.595 17 12.175 17 4.005 15 4.005 15 12.175 12.41 9.595 11 11.005 16 16.005 21 11.005 19.59 9.595"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "4.958",
        "x": "6.854",
        "y": "13.374",
        "transform": "rotate(-45 7.86 15.856)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "5",
        "height": "2",
        "x": "2",
        "y": "22.005"
      }
    }), children]);
  }
};

export default virtual_Sunset24;
